Index: include/asterisk/monitor.h
===================================================================
--- include/asterisk/monitor.h	(rvision 46785)
+++ include/asterisk/monitor.h	(copie de travail)
@@ -46,7 +46,8 @@
 
 /* Start monitoring a channel */
 int ast_monitor_start(struct ast_channel *chan, const char *format_spec,
-		      const char *fname_base, int need_lock );
+		      const char *fname_base, int need_lock, int onlyinput,
+		      int onlyoutput);
 
 /* Stop monitoring a channel */
 int ast_monitor_stop(struct ast_channel *chan, int need_lock);
Index: res/res_monitor.c
===================================================================
--- res/res_monitor.c	(rvision 46785)
+++ res/res_monitor.c	(copie de travail)
@@ -85,6 +85,10 @@
 "          administrator interface\n"
 "\n"
 "    b   - Don't begin recording unless a call is bridged to another channel\n"
+"\n"
+"    i   - Record only input stream\n"
+"\n"
+"    o   - Record only output stream\n"
 "\nReturns -1 if monitor files can't be opened or if the channel is already\n"
 "monitored, otherwise 0.\n"
 ;
@@ -125,7 +129,7 @@
 
 /* Start monitoring a channel */
 int ast_monitor_start(	struct ast_channel *chan, const char *format_spec,
-		const char *fname_base, int need_lock)
+		const char *fname_base, int need_lock, int onlyinput, int onlyoutput)
 {
 	int res = 0;
 	char tmp[256];
@@ -195,7 +199,8 @@
 		if (ast_fileexists(monitor->read_filename, NULL, NULL) > 0) {
 			ast_filedelete(monitor->read_filename, NULL);
 		}
-		if (!(monitor->read_stream = ast_writefile(monitor->read_filename,
+		if (!onlyoutput && !(monitor->read_stream = ast_writefile(
+						monitor->read_filename,
 						monitor->format, NULL,
 						O_CREAT|O_TRUNC|O_WRONLY, 0, 0644))) {
 			ast_log(LOG_WARNING, "Could not create file %s\n",
@@ -207,7 +212,10 @@
 		if (ast_fileexists(monitor->write_filename, NULL, NULL) > 0) {
 			ast_filedelete(monitor->write_filename, NULL);
 		}
-		if (!(monitor->write_stream = ast_writefile(monitor->write_filename,
+		if (onlyoutput)
+			monitor->read_stream = NULL;
+		if (!onlyinput && !(monitor->write_stream = ast_writefile(
+						monitor->write_filename,
 						monitor->format, NULL,
 						O_CREAT|O_TRUNC|O_WRONLY, 0, 0644))) {
 			ast_log(LOG_WARNING, "Could not create file %s\n",
@@ -217,6 +225,8 @@
 			UNLOCK_IF_NEEDED(chan, need_lock);
 			return -1;
 		}
+		if (onlyinput)
+			monitor->write_stream = NULL;
 		chan->monitor = monitor;
 		ast_monitor_set_state(chan, AST_MONITOR_RUNNING);
 		/* so we know this call has been monitored in case we need to bill for it or something */
@@ -396,6 +406,8 @@
 	char tmp[256];
 	int joinfiles = 0;
 	int waitforbridge = 0;
+	int onlyinput = 0;
+	int onlyoutput = 0;
 	int res = 0;
 	
 	/* Parse arguments. */
@@ -409,10 +421,21 @@
 			if ((options = strchr(fname_base, '|'))) {
 				*options = 0;
 				options++;
-				if (strchr(options, 'm'))
+				if (strchr(options, 'm')) {
 					joinfiles = 1;
+					onlyinput = 0;
+					onlyoutput = 0;
+				}
 				if (strchr(options, 'b'))
 					waitforbridge = 1;
+				if (strchr(options, 'i')) {
+					onlyinput = 1;
+					joinfiles = 0;
+				}
+				if (strchr(options, 'o')) {
+					onlyoutput = 1;
+					joinfiles = 0;
+				}
 			}
 		}
 		arg = strchr(format,':');
@@ -445,7 +468,7 @@
 		return 0;
 	}
 
-	res = ast_monitor_start(chan, format, fname_base, 1);
+	res = ast_monitor_start(chan, format, fname_base, 1, onlyinput, onlyoutput);
 	if (res < 0)
 		res = ast_monitor_change_fname(chan, fname_base, 1);
 	ast_monitor_setjoinfiles(chan, joinfiles);
@@ -508,7 +531,7 @@
 			*d = '-';
 	}
 	
-	if (ast_monitor_start(c, format, fname, 1)) {
+	if (ast_monitor_start(c, format, fname, 1, 0, 0)) {
 		if (ast_monitor_change_fname(c, fname, 1)) {
 			astman_send_error(s, m, "Could not start monitoring channel");
 			ast_channel_unlock(c);
